//                                               -*- C++ -*-
/**
 *  @file  PersistentObject.cxx
 *  @brief Class PersistentObject saves and reloads the object's internal state
 *
 *  (C) Copyright 2005-2012 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: lebrun $
 *  @date:   $LastChangedDate: 2012-03-20 06:42:21 +0100 (Tue, 20 Mar 2012) $
 *  Id:      $Id: PersistentObject.cxx 2428 2012-03-20 05:42:21Z lebrun $
 */
#include "PersistentObject.hxx"
#include "OTprivate.hxx"

BEGIN_NAMESPACE_OPENTURNS

/*
 * The default name of any object
 */
const String DefaultName = String(
#ifdef OBJECT_DEFAULT_NAME
                                  OBJECT_DEFAULT_NAME
#else
                                  "Unnamed"
#endif
                                  );



CLASSNAMEINIT(PersistentObject);

/* Method save() stores the object through the StorageManager */
void PersistentObject::save(StorageManager & mgr, const String & label, bool fromStudy) const
{
  if (! mgr.isSavedObject(id_)) {
    Pointer<Advocate> p_adv ( mgr.registerObject(*this, fromStudy) );
    p_adv->setLabel( label );
    save(*p_adv);
    p_adv->saveObject();
    mgr.markObjectAsSaved(id_);
  }
}

/* Method save() stores the object through the StorageManager */
void PersistentObject::save(StorageManager & mgr, bool fromStudy) const
{
  if (! mgr.isSavedObject(id_)) {
    Pointer<Advocate> p_adv ( mgr.registerObject(*this, fromStudy) );
    save(*p_adv);
    p_adv->saveObject();
    mgr.markObjectAsSaved(id_);
  }
}

/* Method save() stores the object through the StorageManager */
void PersistentObject::save(Advocate & adv) const
{
  adv.saveAttribute( "class", getClassName() );
  adv.saveAttribute( "id", id_ );
  if (hasName()) adv.saveAttribute( "name", getName() );
}

/* Method load() reloads the object from the StorageManager */
void PersistentObject::load(Advocate & adv)
{
  adv.loadAttribute( "id", shadowedId_);
  String name;
  adv.loadAttribute( "name", name );
  if (name == DefaultName) p_name_.reset();
  else setName(name);
}


END_NAMESPACE_OPENTURNS
